/* Own Style */
ul > li.metadata-list-item {
    margin-left: 2rem;
    list-style-type: circle;
}

pre {
    /*Use scroll bar if required*/
    overflow: auto;
}

code {
    /*Do not wrap text at whitespace, use scroll bars*/
    overflow: auto;
    white-space: nowrap;
}

.code-block {
    display: block;
    padding: 15px;
    margin-bottom: 15px;
    direction: ltr;
    font-family: Source Code Pro, monospace;
    background-color: #f9f9f9;
    border: 1px solid #d3d3d3;
    font-size: .85rem;
    color: #6c6c6c;
}

/* Users Page*/
.user {
    display: inline-block;
    width: 40%;
}
.user_role {
    display: inline-block;
    width: 40%;
}

/* Flashing */
.flashing {
    margin: .5rem 0 0 0;
    padding: 1rem;
    min-height: 2rem;
    box-shadow: 0 2px 2px 0 rgb(0 0 0 / 14%), 0 3px 1px -2px rgb(0 0 0 / 12%), 0 1px 5px 0 rgb(0 0 0 / 20%);
    -webkit-box-shadow: 0 2px 2px 0 rgb(0 0 0 / 14%), 0 3px 1px -2px rgb(0 0 0 / 12%), 0 1px 5px 0 rgb(0 0 0 / 20%);
}

.material-icons {
    display: inline-flex;
    vertical-align: middle;
}

/* Utils */
.mt-m {
    margin-top: 5rem;
}

.ml-s {
    margin-left: 3rem;
}

.mr-s {
    margin-right: 3rem;
}

/* Overwrites */
.collection .collection-item.avatar {
    min-height: 62px;
}
